@@ -942,14 +942,14 @@ void load_modules(int mod_verb) {
    * Let's iterate over these modules and load them once at a time
    */
   save_ptr = module_list;
-  module = strtok_r(module_list, " ", &save_ptr);
+  module = strtok_r(module_list, " ,", &save_ptr);
   while (module) {
     DPRINTF("loading module %s\n", module);
     int loaded = __load_all_modules(module);
     if (!loaded)
       fprintf(stderr, "Cannot find module '%s'\n", module);
     nb_loaded += loaded;
-    module = strtok_r(NULL, " ", &save_ptr);
+    module = strtok_r(NULL, " ,", &save_ptr);
   }
   out: if (mod_verb)
     printf("%d modules loaded\n", nb_loaded);
