@@ -59,6 +59,8 @@ struct eztrace_container_t {
   struct trace_t *p_trace; /* pointer to the trace that describe this process */
   struct hierarchical_array* arrays;
   struct eztrace_counter* counters;
+  double start_timestamp;	/* date of creation */
+  double end_timestamp;		/* date of destruction */
 };
 
 struct expected_code_t {
