@@ -203,7 +203,7 @@ void eztrace_set_alarm() {
     sevp.sigev_value.sival_int=0;
     sevp.sigev_notify_function = NULL;
     sevp.sigev_notify_attributes=NULL;
-    sevp._sigev_un._tid = CUR_TID;
+    sevp._sigev_un._tid = gettid();
 
     timer_t *t = malloc(sizeof(timer_t));
     int ret = timer_create(CLOCK_REALTIME, &sevp, t);
