@@ -414,18 +414,29 @@ static inline int ezt_get_global_rank_generic(int trace_id, app_ptr comm,
 {
   INIT_MPI_PROCESS_INFO(GET_PROCESS_INFO(trace_id), p_info);
 
-  if (p_info->__MPI_COMM_WORLD.comm_id == comm)
+  if (p_info->__MPI_COMM_WORLD.comm_id == comm) {
     return local_rank;
+  }
 
-  if (p_info->__MPI_COMM_SELF.comm_id == comm)
+  if (p_info->__MPI_COMM_SELF.comm_id == comm) {
     return trace_id;
+  }
 
   /* the communicator in use isn't MPI_COMM_WORLD,
    * let's browse the list
    */
   struct ezt_list_token_t *token;
-  ezt_list_foreach(&p_info->communicators, token)
-  {
+  ezt_list_foreach(&p_info->communicators, token)  {
+    struct ezt_mpi_comm* p_comm = (struct ezt_mpi_comm*) token->data;
+    assert(p_comm);
+    if (p_comm->comm_id == comm) {
+      /* we found the communicator ! */
+      assert(p_comm->comm_size > local_rank);
+      return p_comm->ranks[local_rank];
+    }
+  }
+
+  ezt_list_foreach(&p_info->deleted_communicators, token) {
     struct ezt_mpi_comm* p_comm = (struct ezt_mpi_comm*) token->data;
     assert(p_comm);
     if (p_comm->comm_id == comm) {
