@@ -4,7 +4,6 @@
  * See COPYING in top-level directory.
  */
 
-#define _GNU_SOURCE         /* See feature_test_macros(7) */
 #include <assert.h>
 #include <stdio.h>
 #include "mpi_ev_codes.h"
@@ -32,7 +31,7 @@ void __print_coll_message_header(FILE*stream) {
 }
 
 void __print_coll_message(FILE*stream, struct mpi_coll_msg_t *msg) {
-  fprintf(stream, "[%p]\t%s\t%d\t", msg, COLL_TYPE_STR(msg->type), msg->root_process);
+  fprintf(stream, "[%p]\t%s\t%d\t", msg, COLL_TYPE_STR(msg->type), ezt_get_global_rank(msg->comm[0], msg->root_process));
   int i;
   for (i = 0; i < msg->comm_size; i++) {
     fprintf(stream, "[%s %lu %lu] ", msg->thread_ids[i],
