@@ -597,8 +597,7 @@ int pptrace_wait_library(pid_t child, pptrace_internal_binary* binary) {
   word_uint fd;
 
   /* TODO: either wait for both syscalls or detect how the current system opens shared libraries */
-#if 1
-
+#if USE_OPENAT
   /* wait until ld uses openat("lib.so") */
   int r = trace_wait_syscall(child, &fd, TRACE_SYSCALL(openat),
 			     SYSCALL_ARGTYPE_IGNORE,
